AssetTag

Enum AssetTag 

#[repr(i32)]
pub enum AssetTag { GalleryMeta = 0, GalleryItem = 1, DriveMeta = 2, DriveItem = 3, }
Classifies an asset into a logical section of the Android client.

Stored as an i32 in SQLite to minimize storage footprint. The client uses this tag to route an asset to the correct UI view (gallery or drive) without needing to inspect the encrypted file contents.

Variants



GalleryMeta = 0

Metadata file for the Gallery section (encrypted index, thumbnails, etc.).



GalleryItem = 1

An encrypted media file belonging to the Gallery section.



DriveMeta = 2

Metadata file for the Drive section.



DriveItem = 3

An encrypted file belonging to the Drive section.